@@ -26,6 +26,7 @@ from .literals import (
     CostAllocationTagStatusType,
     CostAllocationTagTypeType,
     DimensionType,
+    GenerationStatusType,
     GranularityType,
     LookbackPeriodInDaysType,
     MetricType,
@@ -69,12 +70,14 @@ from .type_defs import (
     GroupDefinitionTypeDef,
     ListCostAllocationTagsResponseTypeDef,
     ListCostCategoryDefinitionsResponseTypeDef,
+    ListSavingsPlansPurchaseRecommendationGenerationResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ProvideAnomalyFeedbackResponseTypeDef,
     ResourceTagTypeDef,
     RightsizingRecommendationConfigurationTypeDef,
     ServiceSpecificationTypeDef,
     SortDefinitionTypeDef,
+    StartSavingsPlansPurchaseRecommendationGenerationResponseTypeDef,
     SubscriberTypeDef,
     TotalImpactFilterTypeDef,
     UpdateAnomalyMonitorResponseTypeDef,
@@ -104,6 +107,7 @@ class Exceptions:
     BillExpirationException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     DataUnavailableException: Type[BotocoreClientError]
+    GenerationExistsException: Type[BotocoreClientError]
     InvalidNextTokenException: Type[BotocoreClientError]
     LimitExceededException: Type[BotocoreClientError]
     RequestChangedException: Type[BotocoreClientError]
@@ -155,7 +159,8 @@ class CostExplorerClient(BaseClient):
         ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateAnomalyMonitorResponseTypeDef:
         """
-        .
+        Creates a new cost anomaly detection monitor with the requested type and monitor
+        specification.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#create_anomaly_monitor)
@@ -168,7 +173,7 @@ class CostExplorerClient(BaseClient):
         ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
-        .
+        Adds an alert subscription to a cost anomaly detection monitor.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#create_anomaly_subscription)
@@ -186,7 +191,7 @@ class CostExplorerClient(BaseClient):
         ResourceTags: Sequence[ResourceTagTypeDef] = ...
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        .
+        Creates a new Cost Category with the requested name and rules.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#create_cost_category_definition)
@@ -489,8 +494,7 @@ class CostExplorerClient(BaseClient):
         Filter: "ExpressionTypeDef" = ...
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        Retrieves your request parameters, Savings Plan Recommendations Summary and
-        Details.
+        Retrieves the Savings Plans recommendations for your account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#get_savings_plans_purchase_recommendation)
@@ -592,9 +596,26 @@ class CostExplorerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#list_cost_category_definitions)
         """
 
+    def list_savings_plans_purchase_recommendation_generation(
+        self,
+        *,
+        GenerationStatus: GenerationStatusType = ...,
+        RecommendationIds: Sequence[str] = ...,
+        PageSize: int = ...,
+        NextPageToken: str = ...
+    ) -> ListSavingsPlansPurchaseRecommendationGenerationResponseTypeDef:
+        """
+        Retrieves a list of your historical recommendation generations within the past
+        30 days.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.list_savings_plans_purchase_recommendation_generation)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#list_savings_plans_purchase_recommendation_generation)
+        """
+
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        .
+        Returns a list of resource tags associated with the resource specified by the
+        Amazon Resource Name (ARN).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#list_tags_for_resource)
@@ -610,11 +631,21 @@ class CostExplorerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#provide_anomaly_feedback)
         """
 
+    def start_savings_plans_purchase_recommendation_generation(
+        self,
+    ) -> StartSavingsPlansPurchaseRecommendationGenerationResponseTypeDef:
+        """
+        Requests a Savings Plans recommendation generation.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.start_savings_plans_purchase_recommendation_generation)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#start_savings_plans_purchase_recommendation_generation)
+        """
+
     def tag_resource(
         self, *, ResourceArn: str, ResourceTags: Sequence[ResourceTagTypeDef]
     ) -> Dict[str, Any]:
         """
-        .
+        An API operation for adding one or more tags (key-value pairs) to a resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ce.html#CostExplorer.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/client/#tag_resource)
@@ -646,7 +677,8 @@ class CostExplorerClient(BaseClient):
         Frequency: AnomalySubscriptionFrequencyType = ...,
         MonitorArnList: Sequence[str] = ...,
         Subscribers: Sequence[SubscriberTypeDef] = ...,
-        SubscriptionName: str = ...
+        SubscriptionName: str = ...,
+        ThresholdExpression: "ExpressionTypeDef" = ...
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
         Updates an existing cost anomaly monitor subscription.
